function [traveltime_scatter, angle_scatter, sign_scatter, incidence_station] = cal_time_angle_slw(model, dist, depth, station, slowness)
    
    % model parameters
    moho        = model.moho_depth;
    phi_dipping = model.moho_dipping;
    Vp_crust    = model.Vp_crust;
    Vs_crust    = model.Vs_crust;
    Vp_mantle   = model.Vp_mantle;
    Vs_mantle   = model.Vs_mantle;

    % angles 
    theta_P = asind(slowness*Vp_mantle);       % incidence of P wave at second layer
    
    tmp_depth = moho + dist*tand(phi_dipping);
    if ( depth > tmp_depth )    % below the moho
        time_p1 = -(depth - moho - dist*tand(theta_P))*cosd(theta_P)/Vp_mantle;
        
        % rotate to flat interface
        dist_g = (depth - tmp_depth) * cosd(phi_dipping);
        dist_x = (moho + station*tand(phi_dipping)) * cosd(phi_dipping);
        length_gx = (station - dist)/cosd(phi_dipping) - dist_g * tand(phi_dipping) - dist_x * tand(phi_dipping);
        

        C4 = Vs_crust^2 - Vs_mantle^2;
        C3 = -2*length_gx*C4;
        C2 = Vs_crust^2 * (dist_x^2 + length_gx^2) - Vs_mantle^2 * (dist_g^2 + length_gx^2);
        C1 = 2*length_gx*Vs_mantle^2*dist_g^2;
        C0 = -1*Vs_mantle^2*length_gx^2*dist_g^2;
        
        x_solu = roots([C4 C3 C2 C1 C0]);
        x_inter = -1;
        for ii = 1:length(x_solu)
            if ( ~ isreal(x_solu(ii)))
                continue;
            end
            if ( (x_solu(ii) >= 0 && x_solu(ii) <= length_gx) || (x_solu(ii) <= 0 && x_solu(ii) >= length_gx) )
                x_inter = dist + (dist_g * sind(phi_dipping) + x_solu(ii))*cosd(phi_dipping);
                break;
            end
        end
        
        if( x_inter == -1 )
            traveltime_scatter = -1.0;
            return;
        end

         
        d_inter = x_inter * tand(phi_dipping) + moho;
        time_s2 = sqrt((depth - d_inter)^2 + (dist - x_inter)^2)/Vs_mantle + sqrt((x_inter - station)^2 + (d_inter)^2)/Vs_crust;
        traveltime_scatter = time_p1 + time_s2;
        
        h_g = (depth - (dist*tand(phi_dipping) + moho)) * cosd(phi_dipping);
        w_g = (depth - (dist*tand(phi_dipping) + moho)) * sind(phi_dipping) + (dist - x_inter)/cosd(phi_dipping);
        angle_tmp = atand(w_g/h_g);
%         angle_scatter = sign(slowness)*(angle_tmp + 180.0 - theta_P);
        angle_scatter = phi_dipping - angle_tmp - theta_P;

		sign_scatter = -1 * sign(slowness);
        
        incidence_station = abs(atand((x_inter - station)/(d_inter)));
        
        return;
    else                        % above the moho
        alpha = asind(sind(phi_dipping - theta_P)*Vp_crust/Vp_mantle);
        x_inter = (dist + (depth - moho)*tand(phi_dipping - alpha))/(1 + tand(phi_dipping)*tand(phi_dipping - alpha));
        d_inter = x_inter * tand(phi_dipping) + moho;
        time_p1 = -(x_inter * sind(phi_dipping - theta_P)/(Vp_mantle * cosd(phi_dipping))) + sqrt((dist-x_inter)^2 + (depth-d_inter)^2)/Vp_crust;
        time_s2 = sqrt((dist - station)^2 + (depth)^2)/Vs_crust;
        traveltime_scatter = time_p1 + time_s2;
        
        h_g = depth;
        w_g = station - dist;
        angle_tmp = atand(w_g/h_g);
        angle_scatter = angle_tmp - (phi_dipping - alpha);

		sign_scatter = -1 * sign(slowness);
        
        incidence_station = abs(atand((dist - station)/(depth)));
        
        return;
    end
    
end
